@@ -24,7 +24,7 @@ __docformat__ = "restructuredtext en"
 modname = "yams"
 
 # release version
-numversion = (0, 47, 0)
+numversion = (0, 48, 0)
 version = ".".join(str(num) for num in numversion)
 
 # license and copyright
@@ -38,7 +38,7 @@ author = "Logilab"
 author_email = "devel@logilab.fr"
 
 # home page
-web = "https://www.logilab.org/project/%s" % modname
+web = "https://forge.extranet.logilab.fr/open-source/%s" % modname
 
 # mailing list
 mailinglist = "mailto://python-projects@lists.logilab.org"
@@ -48,7 +48,7 @@ scripts = ["bin/yams-check", "bin/yams-view"]
 
 install_requires = [
     "setuptools",
-    "logilab-common >= 1.6.0",
+    "logilab-common >= 1.9.0",
     "logilab-database >= 1.11",
 ]
 
