@@ -89,7 +89,7 @@ def _RELATION_DEFINITION_PROPERTIES() -> Tuple[str, ...]:
 
 
 _RDEF_PROPERTIES = deprecation.callable_renamed(
-    old_name="_RDEF_PROPERTIES", new_function=_RELATION_DEFINITION_PROPERTIES
+    old_name="_RDEF_PROPERTIES", new_function=_RELATION_DEFINITION_PROPERTIES, version="0.48"
 )
 
 
@@ -102,7 +102,7 @@ def _RELATION_PROPERTIES() -> Tuple[str, ...]:
 
 
 _REL_PROPERTIES = deprecation.callable_renamed(
-    old_name="_REL_PROPERTIES", new_function=_RELATION_PROPERTIES
+    old_name="_REL_PROPERTIES", new_function=_RELATION_PROPERTIES, version="0.48"
 )
 
 
@@ -126,8 +126,8 @@ def _add_constraint(kwargs: Dict[str, Any], constraint: BaseConstraint) -> None:
     constraints.append(constraint)
 
 
-@deprecation.argument_renamed(old_name="rdef", new_name="relation_definition")
-@deprecation.argument_renamed(old_name="insertidx", new_name="insert_index")
+@deprecation.argument_renamed(old_name="rdef", new_name="relation_definition", version="0.48")
+@deprecation.argument_renamed(old_name="insertidx", new_name="insert_index", version="0.48")
 def _add_relation(
     relations: List["RelationDefinition"],
     relation_definition: "RelationDefinition",
@@ -167,8 +167,8 @@ def _check_kwargs(kwargs: Dict[_KwargsKeyType, Any], attributes: Sequence[_Kwarg
             raise BadSchemaDefinition("no such property %r in %r" % (key, attributes))
 
 
-@deprecation.argument_renamed(old_name="fromobj", new_name="from_object")
-@deprecation.argument_renamed(old_name="toobj", new_name="to_object")
+@deprecation.argument_renamed(old_name="fromobj", new_name="from_object", version="0.48")
+@deprecation.argument_renamed(old_name="toobj", new_name="to_object", version="0.48")
 def _copy_attributes(from_object: Any, to_object: Any, attributes: Iterable[str]) -> None:
     for attribute in attributes:
         value = getattr(from_object, attribute, MARKER)
@@ -255,7 +255,7 @@ class Definition(object, metaclass=autopackage):
         return self.__permissions__
 
     @classmethod
-    @deprecation.argument_renamed(old_name="perms", new_name="permissions")
+    @deprecation.argument_renamed(old_name="perms", new_name="permissions", version="0.48")
     def set_permissions(cls: Type["Definition"], permissions: yams_types.Permissions) -> None:
         cls.__permissions__ = permissions
 
@@ -264,13 +264,13 @@ class Definition(object, metaclass=autopackage):
 
 # has to be defined before the metadefinition metaclass which "isinstance" this
 # class
-@deprecation.attribute_renamed(old_name="etype", new_name="entity_type")
+@deprecation.attribute_renamed(old_name="etype", new_name="entity_type", version="0.48")
 class ObjectRelation:
     __permissions__ = MARKER
     cardinality = MARKER
     constraints = MARKER
 
-    @deprecation.argument_renamed(old_name="etype", new_name="entity_type")
+    @deprecation.argument_renamed(old_name="etype", new_name="entity_type", version="0.48")
     def __init__(self, entity_type: str, override: bool = False, **kwargs) -> None:
         if self.__class__.__name__ == "ObjectRelation":
             warn(
@@ -413,7 +413,7 @@ class AbstractTypedAttribute(SubjectRelation):
         return "<%(name)s(%(entity_type)s)>" % self.__dict__
 
 
-@deprecation.argument_renamed(old_name="etype", new_name="entity_type")
+@deprecation.argument_renamed(old_name="etype", new_name="entity_type", version="0.48")
 def make_type(entity_type: str) -> Type[AbstractTypedAttribute]:
     """create a python class for a Yams base type.
 
@@ -764,7 +764,7 @@ class EntityType(Definition, metaclass=metadefinition):
 
     @classmethod
     @deprecation.attribute_renamed(
-        old_name="othermetadefcls", new_name="other_meta_definition_class"
+        old_name="othermetadefcls", new_name="other_meta_definition_class", version="0.48"
     )
     def extend(cls: Type["EntityType"], other_meta_definition_class) -> None:
         """add all relations of ``other_meta_definition_class`` to the current class"""
@@ -772,7 +772,7 @@ class EntityType(Definition, metaclass=metadefinition):
             cls.add_relation(relation_definition)
 
     @classmethod
-    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition")
+    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition", version="0.48")
     def add_relation(
         cls: Type["EntityType"], relation_definition: ObjectRelation, name: Optional[str] = None
     ) -> None:
@@ -802,8 +802,10 @@ class EntityType(Definition, metaclass=metadefinition):
             _add_relation(cls.__relations__, relation_definition, name=name)  # type: ignore
 
     @classmethod
-    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition")
-    @deprecation.argument_renamed(old_name="afterrelname", new_name="after_relation_name")
+    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition", version="0.48")
+    @deprecation.argument_renamed(
+        old_name="afterrelname", new_name="after_relation_name", version="0.48"
+    )
     def insert_relation_after(
         cls: Type["EntityType"],
         after_relation_name: str,
@@ -1111,7 +1113,7 @@ class RelationDefinition(Definition):
                 schema.add_relation_def(relation_definition)
 
 
-@deprecation.argument_renamed(old_name="etype", new_name="entity_type")
+@deprecation.argument_renamed(old_name="etype", new_name="entity_type", version="0.48")
 def _actual_types(
     schema: yams_types.Schema, entity_type: Union[str, list, Tuple[Any, Any]]
 ) -> Union[Generator[Any, Any, None], Tuple[Any], Tuple, List, Any]:
