@@ -458,7 +458,7 @@ class BoundaryConstraint(BaseConstraint):
         return "BoundaryConstraint"
 
 
-BoundConstraint = class_renamed("BoundConstraint", BoundaryConstraint)
+BoundConstraint = class_renamed("BoundConstraint", BoundaryConstraint, version="0.48")
 
 _("value %(KEY-value)s must be < %(KEY-boundary)s")
 _("value %(KEY-value)s must be > %(KEY-boundary)s")
