@@ -60,9 +60,11 @@ for object_name in dir(constraints):
         continue
 
 
-@deprecation.argument_renamed(old_name="erdefs", new_name="entity_relation_definitions")
 @deprecation.argument_renamed(
-    old_name="remove_unused_rtypes", new_name="remove_unused_relation_types"
+    old_name="erdefs", new_name="entity_relation_definitions", version="0.48"
+)
+@deprecation.argument_renamed(
+    old_name="remove_unused_rtypes", new_name="remove_unused_relation_types", version="0.48"
 )
 def fill_schema(
     schema: yams_types.Schema,
@@ -120,8 +122,8 @@ def fill_schema(
     return schema
 
 
-@deprecation.attribute_renamed(old_name="schemacls", new_name="schema_class")
-@deprecation.attribute_renamed(old_name="extrapath", new_name="extra_path")
+@deprecation.attribute_renamed(old_name="schemacls", new_name="schema_class", version="0.48")
+@deprecation.attribute_renamed(old_name="extrapath", new_name="extra_path", version="0.48")
 class SchemaLoader:
     """the schema loader is responsible to build a schema object from a
     set of files
@@ -135,9 +137,9 @@ class SchemaLoader:
     context.update(CONSTRAINTS)
 
     @deprecation.argument_renamed(
-        old_name="remove_unused_rtypes", new_name="remove_unused_relation_types"
+        old_name="remove_unused_rtypes", new_name="remove_unused_relation_types", version="0.48"
     )
-    @deprecation.argument_renamed(old_name="modnames", new_name="module_names")
+    @deprecation.argument_renamed(old_name="modnames", new_name="module_names", version="0.48")
     def load(
         self,
         module_names: Sequence[Tuple[Any, str]],
@@ -221,7 +223,7 @@ class SchemaLoader:
                 with tempattr(buildobjs, "PACKAGE", package):
                     self.handle_file(file_path, None)
 
-    @deprecation.argument_renamed(old_name="modnames", new_name="module_names")
+    @deprecation.argument_renamed(old_name="modnames", new_name="module_names", version="0.48")
     def _load_module_names(self, module_names: Sequence[Tuple[Any, str]]) -> None:
         for package, module_name in module_names:
             loader = pkgutil.find_loader(module_name)
@@ -244,7 +246,7 @@ class SchemaLoader:
                 self.handle_file(file_path, module_name=module_name)
 
     _load_modnames = deprecation.callable_renamed(
-        old_name="_load_modnames", new_function=_load_module_names
+        old_name="_load_modnames", new_function=_load_module_names, version="0.48"
     )
 
     # has to be overridable sometimes (usually for test purpose)
@@ -280,8 +282,8 @@ class SchemaLoader:
 
         return result
 
-    @deprecation.argument_renamed(old_name="filepath", new_name="file_path")
-    @deprecation.argument_renamed(old_name="modname", new_name="module_name")
+    @deprecation.argument_renamed(old_name="filepath", new_name="file_path", version="0.48")
+    @deprecation.argument_renamed(old_name="modname", new_name="module_name", version="0.48")
     def handle_file(self, file_path: str, module_name: Optional[str] = None) -> None:
         """handle a partial schema definition file according to its extension"""
         assert file_path.endswith(".py"), "not a python file"
@@ -309,14 +311,16 @@ class SchemaLoader:
 
             self.loaded_files.append(file_path)
 
-    @deprecation.argument_renamed(old_name="filepath", new_name="file_path")
+    @deprecation.argument_renamed(old_name="filepath", new_name="file_path", version="0.48")
     def unhandled_file(self, file_path: str) -> None:
         """called when a file without handler associated has been found,
         does nothing by default.
         """
 
-    @deprecation.argument_renamed(old_name="filepath", new_name="file_path")
-    @deprecation.argument_renamed(old_name="defobject", new_name="definition_object")
+    @deprecation.argument_renamed(old_name="filepath", new_name="file_path", version="0.48")
+    @deprecation.argument_renamed(
+        old_name="defobject", new_name="definition_object", version="0.48"
+    )
     def add_definition(
         self, definition_object: Type[buildobjs.Definition], file_path: Optional[str] = None
     ) -> None:
@@ -331,8 +335,8 @@ class SchemaLoader:
 
         definition_object.expand_type_definitions(self.defined)
 
-    @deprecation.argument_renamed(old_name="filepath", new_name="file_path")
-    @deprecation.argument_renamed(old_name="modname", new_name="module_name")
+    @deprecation.argument_renamed(old_name="filepath", new_name="file_path", version="0.48")
+    @deprecation.argument_renamed(old_name="modname", new_name="module_name", version="0.48")
     def exec_file(self, file_path: str, module_name: Optional[str]) -> Tuple[str, types.ModuleType]:
         if module_name is None:
             try:
