@@ -74,7 +74,7 @@ __docformat__: str = "restructuredtext en"
 _: Type[str] = str
 
 
-@deprecation.argument_renamed(old_name="rtype", new_name="relation_type")
+@deprecation.argument_renamed(old_name="rtype", new_name="relation_type", version="0.48")
 def role_name(relation_type, role) -> str:
     """function to use for qualifying attribute / relation in ValidationError
     errors'dictionnary
@@ -118,7 +118,9 @@ def rehash(dictionary: Dict) -> dict:
 class ERSchema:
     """Base class shared by entity and relation schema."""
 
-    @deprecation.argument_renamed(old_name="erdef", new_name="entity_relation_definition")
+    @deprecation.argument_renamed(
+        old_name="erdef", new_name="entity_relation_definition", version="0.48"
+    )
     def __init__(
         self, schema: "Schema", entity_relation_definition: yams_types.RelationDefinition = None
     ) -> None:
@@ -266,8 +268,8 @@ class _RetroCompatRelationsDict(dict):
         return list(self.values())
 
 
-@deprecation.attribute_renamed(old_name="subjrels", new_name="subject_relations")
-@deprecation.attribute_renamed(old_name="objrels", new_name="object_relations")
+@deprecation.attribute_renamed(old_name="subjrels", new_name="subject_relations", version="0.48")
+@deprecation.attribute_renamed(old_name="objrels", new_name="object_relations", version="0.48")
 class EntitySchema(PermissionMixIn, ERSchema):
     """An entity has a type, a set of subject and or object relations
     the entity schema defines the possible relations for a given type and some
@@ -285,7 +287,7 @@ class EntitySchema(PermissionMixIn, ERSchema):
     _specialized_type: Optional[str] = None
     _specialized_by: List = []
 
-    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition")
+    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition", version="0.48")
     def __init__(
         self,
         schema: "Schema" = None,
@@ -351,7 +353,7 @@ class EntitySchema(PermissionMixIn, ERSchema):
 
     # schema building methods #################################################
 
-    @deprecation.argument_renamed(old_name="rschema", new_name="relation_schema")
+    @deprecation.argument_renamed(old_name="rschema", new_name="relation_schema", version="0.48")
     def add_subject_relation(self, relation_schema: "RelationSchema") -> None:
         """register the relation schema as possible subject relation"""
         self.subject_relations[relation_schema] = relation_schema
@@ -359,12 +361,12 @@ class EntitySchema(PermissionMixIn, ERSchema):
         clear_cache(self, "ordered_relations")
         clear_cache(self, "meta_attributes")
 
-    @deprecation.argument_renamed(old_name="rschema", new_name="relation_schema")
+    @deprecation.argument_renamed(old_name="rschema", new_name="relation_schema", version="0.48")
     def add_object_relation(self, relation_schema: "RelationSchema") -> None:
         """register the relation schema as possible object relation"""
         self.object_relations[relation_schema] = relation_schema
 
-    @deprecation.argument_renamed(old_name="rtype", new_name="relation_schema")
+    @deprecation.argument_renamed(old_name="rtype", new_name="relation_schema", version="0.48")
     def del_subject_relation(self, relation_schema: "RelationSchema") -> None:
         try:
             del self.subject_relations[relation_schema]
@@ -373,7 +375,7 @@ class EntitySchema(PermissionMixIn, ERSchema):
         except KeyError:
             pass  # XXX error should never pass silently
 
-    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type")
+    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type", version="0.48")
     def del_object_relation(self, relation_schema: "RelationSchema") -> None:
         if relation_schema in self.object_relations:
             del self.object_relations[relation_schema]
@@ -410,16 +412,16 @@ class EntitySchema(PermissionMixIn, ERSchema):
 
         return subject_schemas
 
-    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type")
+    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type", version="0.48")
     def has_relation(self, relation_type: yams_types.RelationType, role: str) -> bool:
         if role == "subject":
             return relation_type in self.subject_relations
 
         return relation_type in self.object_relations
 
-    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type")
-    @deprecation.argument_renamed(old_name="targettype", new_name="target_type")
-    @deprecation.argument_renamed(old_name="takefirst", new_name="take_first")
+    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type", version="0.48")
+    @deprecation.argument_renamed(old_name="targettype", new_name="target_type", version="0.48")
+    @deprecation.argument_renamed(old_name="takefirst", new_name="take_first", version="0.48")
     def relation_definition(
         self,
         relation_type: yams_types.DefinitionName,
@@ -456,7 +458,9 @@ class EntitySchema(PermissionMixIn, ERSchema):
 
         return relation_schema.role_relation_definition(self.type, target_type, role)
 
-    rdef = deprecation.callable_renamed(old_name="rdef", new_function=relation_definition)
+    rdef = deprecation.callable_renamed(
+        old_name="rdef", new_function=relation_definition, version="0.48"
+    )
 
     @cached
     def ordered_relations(self) -> List["RelationSchema"]:
@@ -472,7 +476,7 @@ class EntitySchema(PermissionMixIn, ERSchema):
         Tuple["RelationSchema", Tuple["EntitySchema", ...], str], Any, None
     ]
 
-    @deprecation.argument_renamed(old_name="includefinal", new_name="include_final")
+    @deprecation.argument_renamed(old_name="includefinal", new_name="include_final", version="0.48")
     def relation_definitions(self, include_final: bool = False) -> "_RelationDefinitionsReturnType":
         """return an iterator on relation definitions
 
@@ -490,7 +494,7 @@ class EntitySchema(PermissionMixIn, ERSchema):
         for relation_schema in self.object_relations.values():
             yield relation_schema, relation_schema.subjects(self), "object"
 
-    @deprecation.argument_renamed(old_name="rtype", new_name="relation_schema")
+    @deprecation.argument_renamed(old_name="rtype", new_name="relation_schema", version="0.48")
     def destination(self, relation_schema: "RelationSchema") -> "EntitySchema":
         """return the type or schema of entities related by the given subject relation
 
@@ -546,7 +550,7 @@ class EntitySchema(PermissionMixIn, ERSchema):
                 if value is not None:
                     yield relation_schema, value
 
-    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type")
+    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type", version="0.48")
     def default(self, relation_type: yams_types.DefinitionName) -> Any:
         """return the default value of a subject relation"""
         relation_definition = self.relation_definition(relation_type, take_first=True)
@@ -564,7 +568,7 @@ class EntitySchema(PermissionMixIn, ERSchema):
 
         return default
 
-    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type")
+    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type", version="0.48")
     def has_unique_values(self, relation_type: yams_types.DefinitionName) -> bool:
         """convenience method to check presence of the UniqueConstraint on a
         relation
@@ -599,14 +603,14 @@ class EntitySchema(PermissionMixIn, ERSchema):
 
         return meta_attributes
 
-    @deprecation.argument_renamed(old_name="attr", new_name="attribute")
+    @deprecation.argument_renamed(old_name="attr", new_name="attribute", version="0.48")
     def has_metadata(self, attribute, metadata) -> Optional["RelationSchema"]:
         """return metadata's relation schema if this entity has the given
         `metadata` field for the given `attribute` attribute
         """
         return self.subject_relations.get("%s_%s" % (attribute, metadata))
 
-    @deprecation.argument_renamed(old_name="attr", new_name="attribute")
+    @deprecation.argument_renamed(old_name="attr", new_name="attribute", version="0.48")
     def is_metadata(self, attribute) -> Optional[Tuple[str, str]]:
         """return a metadata for an attribute (None if unspecified)"""
         try:
@@ -658,7 +662,7 @@ class EntitySchema(PermissionMixIn, ERSchema):
 
     # resource accessors ##############
 
-    @deprecation.argument_renamed(old_name="skiprels", new_name="skip_relations")
+    @deprecation.argument_renamed(old_name="skiprels", new_name="skip_relations", version="0.48")
     def is_subobject(
         self,
         strict: bool = False,
@@ -810,7 +814,7 @@ class EntitySchema(PermissionMixIn, ERSchema):
         else:
             return value
 
-    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type")
+    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type", version="0.48")
     def vocabulary(self, relation_type: yams_types.DefinitionName) -> Tuple[str, ...]:
         """backward compat return the vocabulary of a subject relation"""
         constraint = self.relation_definition(relation_type).constraint_by_interface(
@@ -823,7 +827,7 @@ class EntitySchema(PermissionMixIn, ERSchema):
         return constraint.vocabulary()  # type: ignore # we know it's a StaticVocabularyConstraint
 
 
-@deprecation.attribute_renamed(old_name="rtype", new_name="relation_type")
+@deprecation.attribute_renamed(old_name="rtype", new_name="relation_type", version="0.48")
 class RelationDefinitionSchema(PermissionMixIn):
     """a relation definition is fully caracterized relation, eg
 
@@ -864,7 +868,7 @@ class RelationDefinitionSchema(PermissionMixIn):
             )
         )
 
-    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type")
+    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type", version="0.48")
     def __init__(
         self,
         subject: "EntitySchema",
@@ -928,7 +932,7 @@ class RelationDefinitionSchema(PermissionMixIn):
             )
 
     @classmethod
-    @deprecation.argument_renamed(old_name="desttype", new_name="destination_type")
+    @deprecation.argument_renamed(old_name="desttype", new_name="destination_type", version="0.48")
     def rproperty_defs(cls, destination_type) -> Dict[str, Any]:
         """return a dictionary mapping property name to its definition for each
         allowable properties when the relation has `destination_type` as target entity's
@@ -968,7 +972,7 @@ class RelationDefinitionSchema(PermissionMixIn):
         # this is a dynamically setted attribue using self.__dict__.update(some_dict)
         return self.cardinality[role == "object"]  # type: ignore
 
-    @deprecation.argument_renamed(old_name="cstrtype", new_name="constraint_type")
+    @deprecation.argument_renamed(old_name="cstrtype", new_name="constraint_type", version="0.48")
     def constraint_by_type(self, constraint_type: str) -> Optional[BaseConstraint]:
         # mypy: "RelationDefinitionSchema" has no attribute "constraints"
         # this is a dynamically setted attribue using self.__dict__.update(some_dict)
@@ -987,7 +991,7 @@ class RelationDefinitionSchema(PermissionMixIn):
 
         return None
 
-    @deprecation.argument_renamed(old_name="iface", new_name="interface")
+    @deprecation.argument_renamed(old_name="iface", new_name="interface", version="0.48")
     def constraint_by_interface(self, interface: Type[IConstraint]) -> Optional[BaseConstraint]:
         # mypy: "RelationDefinitionSchema" has no attribute "constraints"
         # this is a dynamically setted attribue using self.__dict__.update(some_dict)
@@ -1011,10 +1015,14 @@ class RelationDefinitionSchema(PermissionMixIn):
             raise BadSchemaDefinition(f"Cannot set add/update permissions on computed {self}")
 
 
-@deprecation.attribute_renamed(old_name="rdefs", new_name="relation_definitions")
-@deprecation.attribute_renamed(old_name="rdef_class", new_name="relation_definition_class")
-@deprecation.attribute_renamed(old_name="_subj_schemas", new_name="_subject_schemas")
-@deprecation.attribute_renamed(old_name="_obj_schemas", new_name="_object_schemas")
+@deprecation.attribute_renamed(old_name="rdefs", new_name="relation_definitions", version="0.48")
+@deprecation.attribute_renamed(
+    old_name="rdef_class", new_name="relation_definition_class", version="0.48"
+)
+@deprecation.attribute_renamed(
+    old_name="_subj_schemas", new_name="_subject_schemas", version="0.48"
+)
+@deprecation.attribute_renamed(old_name="_obj_schemas", new_name="_object_schemas", version="0.48")
 class RelationSchema(ERSchema):
     """A relation is a named and oriented link between two entities.
     A relation schema defines the possible types of both extremities.
@@ -1039,7 +1047,7 @@ class RelationSchema(ERSchema):
     permissions: Optional[yams_types.Permissions] = None
     relation_definition_class = RelationDefinitionSchema
 
-    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition")
+    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition", version="0.48")
     def __init__(
         self, schema: "Schema", relation_definition: yams_types.RelationType = None, **kwargs
     ) -> None:
@@ -1063,7 +1071,7 @@ class RelationSchema(ERSchema):
 
         super(RelationSchema, self).__init__(schema, relation_definition)
 
-    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition")
+    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition", version="0.48")
     def _init_relation(self, relation_definition: yams_types.RelationType) -> None:
         if relation_definition.rule is not MARKER:
             raise BadSchemaDefinition("Relation has no rule attribute")
@@ -1076,7 +1084,7 @@ class RelationSchema(ERSchema):
         # to other side entity (the container)
         self.fulltext_container = relation_definition.fulltext_container or None
 
-    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition")
+    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition", version="0.48")
     def _init_computed_relation(self, relation_definition: yams_types.RelationType) -> None:
         """computed relation are specific relation with only a rule attribute.
 
@@ -1108,9 +1116,9 @@ class RelationSchema(ERSchema):
 
     # schema building methods #################################################
 
-    @deprecation.argument_renamed(old_name="subjschema", new_name="subject_schema")
-    @deprecation.argument_renamed(old_name="objschema", new_name="object_schema")
-    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition")
+    @deprecation.argument_renamed(old_name="subjschema", new_name="subject_schema", version="0.48")
+    @deprecation.argument_renamed(old_name="objschema", new_name="object_schema", version="0.48")
+    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition", version="0.48")
     def update(
         self,
         subject_schema: "EntitySchema",
@@ -1172,7 +1180,7 @@ class RelationSchema(ERSchema):
 
         return relation_definitions
 
-    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition")
+    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition", version="0.48")
     def _add_relation_definition(
         self, relation_definition: yams_types.RelationDefinitionSchema
     ) -> None:
@@ -1207,11 +1215,13 @@ class RelationSchema(ERSchema):
             relation_definition.object.add_object_relation(self)
 
     _add_rdef = deprecation.callable_renamed(
-        old_name="_add_rdef", new_function=_add_relation_definition
+        old_name="_add_rdef", new_function=_add_relation_definition, version="0.48"
     )
 
-    @deprecation.argument_renamed(old_name="subjectschema", new_name="subject_schema")
-    @deprecation.argument_renamed(old_name="objectschema", new_name="object_schema")
+    @deprecation.argument_renamed(
+        old_name="subjectschema", new_name="subject_schema", version="0.48"
+    )
+    @deprecation.argument_renamed(old_name="objectschema", new_name="object_schema", version="0.48")
     def _update(self, subject_schema: "EntitySchema", object_schema: "EntitySchema") -> None:
         object_types = self._subject_schemas.setdefault(subject_schema, [])
 
@@ -1223,8 +1233,8 @@ class RelationSchema(ERSchema):
         if subject_schema not in subject_types:
             subject_types.append(subject_schema)
 
-    @deprecation.argument_renamed(old_name="subjschema", new_name="subject_schema")
-    @deprecation.argument_renamed(old_name="objschema", new_name="object_schema")
+    @deprecation.argument_renamed(old_name="subjschema", new_name="subject_schema", version="0.48")
+    @deprecation.argument_renamed(old_name="objschema", new_name="object_schema", version="0.48")
     def del_relation_def(
         self,
         subject_schema: "EntitySchema",
@@ -1273,7 +1283,9 @@ class RelationSchema(ERSchema):
 
     # XXX move to RelationDefinitionSchema
 
-    @deprecation.argument_renamed(old_name="buildrdef", new_name="build_relation_definition")
+    @deprecation.argument_renamed(
+        old_name="buildrdef", new_name="build_relation_definition", version="0.48"
+    )
     def init_rproperties(
         self,
         subject: "EntitySchema",
@@ -1320,7 +1332,7 @@ class RelationSchema(ERSchema):
         # XXX deprecates in favor of iter_relation_definitions() ?
         return list(self._subject_schemas.items())
 
-    @deprecation.argument_renamed(old_name="etype", new_name="entity_schema")
+    @deprecation.argument_renamed(old_name="etype", new_name="entity_schema", version="0.48")
     def subjects(
         self, entity_schema: Optional["EntitySchema"] = None
     ) -> Tuple["EntitySchema", ...]:
@@ -1339,7 +1351,7 @@ class RelationSchema(ERSchema):
         else:
             raise KeyError(f"{self} does not have {entity_schema} as object")
 
-    @deprecation.argument_renamed(old_name="etype", new_name="entity_schema")
+    @deprecation.argument_renamed(old_name="etype", new_name="entity_schema", version="0.48")
     def objects(self, entity_schema: Optional["EntitySchema"] = None) -> Tuple["EntitySchema", ...]:
         """Return a list of entity schema which can be object of this relation.
 
@@ -1356,7 +1368,7 @@ class RelationSchema(ERSchema):
         except KeyError:
             raise KeyError(f"{self} does not have {entity_schema} as subject")
 
-    @deprecation.argument_renamed(old_name="etype", new_name="entity_schema")
+    @deprecation.argument_renamed(old_name="etype", new_name="entity_schema", version="0.48")
     def targets(
         self, entity_schema: Optional["EntitySchema"] = None, role: str = "subject"
     ) -> Tuple["EntitySchema", ...]:
@@ -1375,10 +1387,12 @@ class RelationSchema(ERSchema):
         else:
             raise KeyError(f"{subject} {self} {object}")
 
-    rdef = deprecation.callable_renamed(old_name="rdef", new_function=relation_definition)
+    rdef = deprecation.callable_renamed(
+        old_name="rdef", new_function=relation_definition, version="0.48"
+    )
 
-    @deprecation.argument_renamed(old_name="etype", new_name="entity_type")
-    @deprecation.argument_renamed(old_name="ttype", new_name="target_type")
+    @deprecation.argument_renamed(old_name="etype", new_name="entity_type", version="0.48")
+    @deprecation.argument_renamed(old_name="ttype", new_name="target_type", version="0.48")
     def role_relation_definition(
         self,
         entity_type: yams_types.DefinitionName,
@@ -1391,7 +1405,7 @@ class RelationSchema(ERSchema):
         return self.relation_definitions[(target_type, entity_type)]
 
     role_rdef = deprecation.callable_renamed(
-        old_name="role_rdef", new_function=role_relation_definition
+        old_name="role_rdef", new_function=role_relation_definition, version="0.48"
     )
 
     def check_permission_definitions(self) -> None:
@@ -1478,7 +1492,7 @@ class Schema:
 
     # schema building methods #################################################
 
-    @deprecation.argument_renamed(old_name="edef", new_name="entity_definition")
+    @deprecation.argument_renamed(old_name="edef", new_name="entity_definition", version="0.48")
     def add_entity_type(self, entity_definition: yams_types.EntityType) -> EntitySchema:
         """Add an entity schema definition for an entity's type.
 
@@ -1499,8 +1513,8 @@ class Schema:
 
         return entity_schema
 
-    @deprecation.argument_renamed(old_name="oldname", new_name="old_name")
-    @deprecation.argument_renamed(old_name="newname", new_name="new_name")
+    @deprecation.argument_renamed(old_name="oldname", new_name="old_name", version="0.48")
+    @deprecation.argument_renamed(old_name="newname", new_name="new_name", version="0.48")
     def rename_entity_type(self, old_name: str, new_name: str) -> None:
         """renames an entity type and update internal structures accordingly"""
         entity_schema = self._entities.pop(old_name)
@@ -1530,7 +1544,9 @@ class Schema:
         # rebuild internal structures since eschema's hash value has changed
         self._rehash()
 
-    @deprecation.argument_renamed(old_name="rtypedef", new_name="relation_type_definition")
+    @deprecation.argument_renamed(
+        old_name="rtypedef", new_name="relation_type_definition", version="0.48"
+    )
     def add_relation_type(
         self, relation_type_definition: yams_types.RelationType
     ) -> RelationSchema:
@@ -1544,7 +1560,7 @@ class Schema:
 
         return relation_schema
 
-    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition")
+    @deprecation.argument_renamed(old_name="rdef", new_name="relation_definition", version="0.48")
     def add_relation_def(
         self, relation_definition: yams_types.RelationDefinition
     ) -> Optional[RelationDefinitionSchema]:
@@ -1589,9 +1605,9 @@ class Schema:
 
         self.critical(message, *args)
 
-    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type")
-    @deprecation.argument_renamed(old_name="subjtype", new_name="subject_type")
-    @deprecation.argument_renamed(old_name="objtype", new_name="object_type")
+    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type", version="0.48")
+    @deprecation.argument_renamed(old_name="subjtype", new_name="subject_type", version="0.48")
+    @deprecation.argument_renamed(old_name="objtype", new_name="object_type", version="0.48")
     def del_relation_def(
         self,
         subject_type: yams_types.DefinitionName,
@@ -1606,7 +1622,7 @@ class Schema:
         if relation_schema.del_relation_def(subject_schema, object_schema):
             del self._relations[relation_type]
 
-    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type")
+    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type", version="0.48")
     def del_relation_type(self, relation_type: "RelationSchema") -> None:
         # XXX don't iter directly on the dictionary since it may be changed
         # by del_relation_def
@@ -1618,7 +1634,7 @@ class Schema:
         if not self.relation_schema_for(relation_type.type).relation_definitions:
             del self._relations[relation_type]
 
-    @deprecation.argument_renamed(old_name="etype", new_name="entity_type")
+    @deprecation.argument_renamed(old_name="etype", new_name="entity_type", version="0.48")
     def del_entity_type(self, entity_type: str) -> None:
         entity_schema = self._entities[entity_type]
 
@@ -1704,7 +1720,7 @@ class Schema:
         """
         return list(self._entities.values())
 
-    @deprecation.argument_renamed(old_name="etype", new_name="entity_type")
+    @deprecation.argument_renamed(old_name="etype", new_name="entity_type", version="0.48")
     def has_entity(self, entity_type: str) -> bool:
         """return true the type is defined in the schema
 
@@ -1717,7 +1733,7 @@ class Schema:
         """
         return entity_type in self._entities
 
-    @deprecation.argument_renamed(old_name="etype", new_name="entity_type")
+    @deprecation.argument_renamed(old_name="etype", new_name="entity_type", version="0.48")
     def entity_schema_for(self, entity_type: yams_types.DefinitionName) -> "EntitySchema":
         """return the entity's schema for the given type
 
@@ -1726,7 +1742,7 @@ class Schema:
         """
         return self._entities[entity_type]
 
-    eschema = deprecation.callable_renamed("eschema", entity_schema_for)
+    eschema = deprecation.callable_renamed("eschema", entity_schema_for, version="0.48")
 
     def relations(self) -> List["RelationSchema"]:
         """return the list of possible relation'types
@@ -1736,7 +1752,7 @@ class Schema:
         """
         return list(self._relations.values())
 
-    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type")
+    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type", version="0.48")
     def has_relation(self, relation_type: yams_types.DefinitionName) -> bool:
         """return true the relation is defined in the schema
 
@@ -1749,7 +1765,7 @@ class Schema:
         """
         return relation_type in self._relations
 
-    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type")
+    @deprecation.argument_renamed(old_name="rtype", new_name="relation_type", version="0.48")
     def relation_schema_for(self, relation_type: yams_types.DefinitionName) -> RelationSchema:
         """return the relation schema for the given type
 
@@ -1760,7 +1776,7 @@ class Schema:
         else:
             raise KeyError(f"No relation named {relation_type} in schema")
 
-    rschema = deprecation.callable_renamed("rschema", relation_schema_for)
+    rschema = deprecation.callable_renamed("rschema", relation_schema_for, version="0.48")
 
     def finalize(self) -> None:
         """Finalize schema
